#ifndef NT2_INCLUDE_FUNCTIONS_INRAD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_INRAD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/inrad.hpp>

#endif
